<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:template match="@*|node()">
  <xsl:copy>
    <xsl:apply-templates select="@*|node()"/>
  </xsl:copy>
</xsl:template>
<xsl:template match="command-option[@name='allow-weak-motifs']">
<code>--allow-weak-motifs</code>
- In p-value score mode, weak motifs
are defined as ones where the best possible hit has a p-value greater
than the p-value threshold.
Such motifs cannot contribute to a match
in p-value score mode. By default, <code>beadstring</code> and
<code>miao</code> reject any search results containing weak motifs, 
unless the -allow-weak-motifs switch is given. 
In that case, the search will proceed,
but the weak motifs will never appear in any matches.
<b>Note</b>:This switch only applies to p-value score mode.
</xsl:template>
<xsl:template match="command-option[@name='bg-file']">
<code>--bg-file <i>&lt;bfile&gt;</i></code>
- Read background frequencies from <code><i>&lt;bfile&gt;</i></code>. 
The default is to calculate the frequencies from the database.
If the argument is the keyword <code>motif-file</code>
the frequencies will be taken from the motif file.
</xsl:template>
<xsl:template match="command-option[@name='comp']">
<code>--comp</code>
- Adjust p-values and E-values for sequence composition.
</xsl:template>
<xsl:template match="command-option[@name='eg-cost']">
<code>--eg-cost <i>&lt;cost&gt;</i></code>
- Scale the expected cost of a
random gap to be <i><code>&lt;cost&gt;</code></i>
times the expected score of a
random hit. By default, gap costs are essentially zero. The larger
you set <i><code>&lt;cost&gt;</code></i>, 
the more gaps will be penalized. 
This can only be used in conjunction with <code>--max-gap</code>. 
This may not be used in conjunction with <code>--min-score</code>.
</xsl:template>
<xsl:template match="command-option[@name='e-thresh']">
<code>--e-thresh <i>&lt;ev&gt;</i></code>
- Print results for cluster with E-value less then 
<code><i>&lt;ev&gt;</i></code> (default: 10).
</xsl:template>
<xsl:template match="command-option[@name='fim']">
<code>--fim</code>
- Gaps between motifs are not penalized.
Spacer states between motifs are represented as free-insertion modules (FIM).
A FIM is an insert state with 1.0 probability of self-transition 
and 1.0 probability of exit transition. 
Thus, traversing such a state has zero transition cost.
Specifying this option causes all spacers to be represented using FIMs.
</xsl:template>
<xsl:template match="command-option[@name='gap-extend']">
<code>--gap-extend <i>&lt;cost&gt;</i></code>
- This switch causes
<b>all</b> spacer self-loop log-odds scores to be set to
<code><i>&lt;cost&gt;</i></code>. 
In addition, it causes all other transitions out of a
spacer to be set to zero. Together with the <code>--gap-open</code>
switch, this allows you to specify an affine gap penalty function,
overriding the gap penalty implicit in the model (self-loop transition
probabilities of gap states).
</xsl:template>
<xsl:template match="command-option[@name='gap-open']">
<code>--gap-open <i>&lt;cost&gt;</i></code>
- This switch causes
<b>all</b> transitions into a spacer state to be assigned a log-odds
score equal to <code><i>&lt;cost&gt;</i></code>.
Together with the <code>--gap-extend</code> switch,
this allows you to specify an affine gap penalty function,
overriding the gap penalty implicit in the model
(transition probabilities into and out of gap states).
</xsl:template>
<xsl:template match="command-option[@name='global']">
<code>--global</code>
- Scores are computed for the match between the entire sequence 
and the model (the default is to use the maximal local score).
</xsl:template>
<xsl:template match="command-option[@name='keep-unused']">
<code>--keep-unused</code>
- By default all inter-motif transitions that are
not observed in the data are removed from the transition probability matrix.
This option allows those transitions to be retained.
This option is only relevant if the model has a
completely connected topology.
</xsl:template>
<xsl:template match="command-option[@name='max-gap']">
<code>--max-gap <i>&lt;max-gap&gt;</i></code>
- The value of <code><i>&lt;max-gap&gt;</i></code> specifies
the longest distance allowed between two hits in a match.
Hits separated by more than <code><i>&lt;max-gap&gt;</i></code> 
will be placed in different matches. 
<b>Note</b>:
Large values of <code><i>&lt;max-gap&gt;</i></code> combined with
large values of <i>pthresh</i> may prevent <code>MCAST</code> from
computing <i>E</i>-values.
</xsl:template>
<xsl:template match="command-option[@name='max-seqs']">
<code>--max-seqs <code><i>&lt;max&gt;</i></code></code>
- Print results for no more than <code><i>&lt;max&gt;</i></code>
sequences.  By default, all matches are reported, up to the specified
p-value threshold (see <code>--output-pthresh</code>).
</xsl:template>
<xsl:template match="command-option[@name='min-score']">
<code>--min-score <i>&lt;minscore&gt;</i></code>
- This switch allows you to
specify the threshold for the repeated match algorithm used by
<code>miao</code>.
Matches must have a score of at least
<code><i>&lt;minscore&gt;</i></code> to be detected.
Matches containing internal regions with scores less than minus 
'threshold' will be split and reported as two separate matches.
</xsl:template>
<xsl:template match="command-option[@name='motif']">
<code>--motif <i>&lt;id&gt;</i></code>
- Use only the motif identified by <code><i>&lt;id&gt;</i></code>. 
This option may be repeated.
</xsl:template>
<xsl:template match="command-option[@name='motif-pseudo']">
<code>--motif-pseudo <i>&lt;float&gt;</i></code>
- A pseudocount to be added to each count in the motif matrix,
after first multiplying by the corresponding background frequency.
The default value is 0.1.
</xsl:template>
<xsl:template match="command-option[@name='motif-scoring']">
<code>--motif-scoring</code>
This option prevents alignments from containing a partial motif.
This option is automatically invoked when you specify
<code>--p-thresh</code>.
You can also set it when you do not want a p-value score
but want to prevent partial matches to motifs.
</xsl:template>
<xsl:template match="command-option[@name='norc']">
<code>--norc</code>
Do not score the reverse complement DNA strand
</xsl:template>
<xsl:template match="command-option[@name='nspacer']">
<code>--nspacer <i>&lt;value&gt;</i></code>
- By default, beadonstring and anoops
model each spacer using a single insert state.
The distribution of spacer lengths produced by a single insert
state is exponential in form.
A more reasonable distribution would be a bell-shaped curve such as a Gaussian.
Modeling the length distribution explicitly is computationally expensive;
however, a Gaussian distribution can be
approximated using multiple insert states to represent a single
spacer region. The <code>--nspacer</code> option specifies the number of
insert states used to represent each spacer.
</xsl:template>
<xsl:template match="command-option[@name='order']">
<code>--order <i>&lt;string&gt;</i></code>
The given string specifies the order and spacing of the motifs within the
model, and has the format "l=n=l=n=...=l=n=l", where "l" is the
length of a region between motifs, and "n" is a motif index. Thus,
for example, the string "34=3=17=2=5" specifies a two-motif linear
model, with motifs 3 and 2 separated by 17 letters and flanked by
34 letters and 5 letters on the left and right. If the motif file
contains motif occurrences on both strands, then the motif IDs in
the order string should be preceded by "+" or "-" indicating the
strandedness of the motif.
</xsl:template>
<xsl:template match="command-option[@name='output-pthresh']">
<code>--output-pthresh <i>&lt;float&gt;</i></code>
- The p-value threshold for displaying search results.
If the p-value of a match is greater than this value,
then the match will not be printed.
The default threshold is 1e-6.
</xsl:template>
<xsl:template match="command-option[@name='p-thresh']">
<code>--p-thresh <i>&lt;float&gt;</i></code>
- The <code>--p-thresh</code> switch
activates p-value score mode with the given threshold. (The default
score mode is called "log-odds score mode".) In p-value score mode,
motif match scores are converted to their p-values. They are then
converted to bit scores as follows:
<div style="margin-left: 2em">S = -log<sub>2</sub>(p/T)</div>
where S is the bit score of the hit,
p is the p-value of the log-odds score,
and T is the p-value threshold.
In this way,
only hits more significant than the p-value threshold get positive scores.
The p-value threshold, T, must be in the range 0&lt;T&lt;=1.
This mode of scoring automatically activates the
<code>--motif-scoring></code> option.
</xsl:template>
<xsl:template match="command-option[@name='pam']">
<code>--pam <i>&lt;distance&gt;</i></code>
- By default, target probabilities are derived
from the <em>distance-250</em> PAM matrix for proteins, and from a
<code><i>&lt;distance&gt;-1</i></code>
transition/transversion matrix for DNA.  
With the <code>-pam</code> switch, 
you can specify a different <b>integer</b> distance
from 1 to 500. (This can be overridden with 
the <code>--score-file</code> switch below). 
The <code><i>&lt;distance&gt;-1</i></code> transition/transversion joint
probability matrix for DNA is given below:

<pre>
       A    C    G    T    
  A  .990 .002 .006 .002
  C  .002 .990 .002 .006
  G  .006 .002 .990 .002
  T  .002 .006 .002 .990
</pre>
</xsl:template>
<xsl:template match="command-option[@name='paths']">
<code>--paths single|all</code>
- This option determines how <code>beadstring</code> computes raw scores.
With the <code>single</code> option,
<code>beadstring</code> computes the Viterbi score,
which is the log-odds score associated with the single
most likely match between the sequence and the model. The
<code>all</code> option yields the total log-odds score,
which is the sum of the log-odds of all sequence-to-model matches.
The default is Viterbi scoring.
</xsl:template>
<xsl:template match="command-option[@name='progress']">
<code>--progress <i>&lt;value&gt;</i></code>
- Print to standard error a progress
message approximately every <code><i>&lt;value&gt;</i></code> seconds.
</xsl:template>
<xsl:template match="command-option[@name='score-file']">
<code>--score-file <i>&lt;score file&gt;</i></code>
- The <code>--score-file</code> switch
causes a score file (in BLAST format) to be read and used instead of
the built-in PAM (for proteins) or transition/transversion (for DNA)ZZ
score file. Several score files are provided (including BLOSUM62) in the
directory <code>doc</code>.
Other, user-provided, score files may be specified as well,
as long as they are in the proper format.
</xsl:template>
<xsl:template match="command-option[@name='sep']">
<code>--sep</code>
- Score reverse complement DNA strand as a separate sequence.
</xsl:template>
<xsl:template match="command-option[@name='seqp']">
<code>--seqp</code>
- Use SEQUENCE p-values for motif thresholds (default: use POSITION p-values).
</xsl:template>
<xsl:template match="command-option[@name='spacer-pseudo']">
<code>--spacer-pseudo <i>&lt;value&gt;</i></code>
- Specify the value of the
pseudocount used in converting transition counts to spacer
self-loop probabilities.
</xsl:template>
<xsl:template match="command-option[@name='synth']">
<code>--synth</code>
- Create synthetic sequences for estimating
<i>E</i>-values. This is useful with small input databases where
not enough match scores are found to estimate <i>E</i>-values.
</xsl:template>
<xsl:template match="command-option[@name='trans-pseudo']">
<code>--trans-pseudo <i>&lt;value&gt;</i></code>
- Specify the value of the
pseudocount used in converting transition counts to transition
probabilities.
</xsl:template>
<xsl:template match="command-option[@name='type']">
<code>--type [complete|star]</code>
- This option specifies the topology of the model.
The <code>complete</code> topology includes
transitions from the end of each motif to the beginning of every
other motif in the model (with a spacer model along each
transition). 
This allows for motifs that are repeated, deleted or shuffled.
In the <code>star</code> topology the transitions from each motif lead to
the intra-motif state. 
The default for <code>miao</code> is the <code>complete</code> topology.
</xsl:template>
<xsl:template match="command-option[@name='verbosity']">
<code>--verbosity 1|2|3|4</code>
- Set the verbosity of status reports to standard error.
The default level is 2.
</xsl:template>
<xsl:template match="command-option[@name='zselo']">
<code>--zselo</code>
Set the verbosity of status reports to standard error.
Spacer emission log-odds scores to be set to zero.
This prevents regions of unusual base/residue composition 
matching spacers well when
the spacer emission frequencies are different than the background frequencies.
It is particularly useful with DNA models.
</xsl:template>
</xsl:stylesheet>
